==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/SecurityType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SecurityType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SecurityType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element name="password" type="{http://schema.webpdf.de/1.0/extraction/info}PasswordType" minOccurs="0"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attGroup ref="{http://schema.webpdf.de/1.0/extraction/info}securityFlags"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SecurityType", propOrder = {
    "password"
})
public class SecurityType {

    protected PasswordType password;
    @XmlAttribute(name = "canAssemble")
    protected Boolean canAssemble;
    @XmlAttribute(name = "canExtractContent")
    protected Boolean canExtractContent;
    @XmlAttribute(name = "canExtractForAccessibility")
    protected Boolean canExtractForAccessibility;
    @XmlAttribute(name = "canFillInForm")
    protected Boolean canFillInForm;
    @XmlAttribute(name = "canModify")
    protected Boolean canModify;
    @XmlAttribute(name = "canModifyAnnotations")
    protected Boolean canModifyAnnotations;
    @XmlAttribute(name = "canPrint")
    protected Boolean canPrint;
    @XmlAttribute(name = "canPrintHighRes")
    protected Boolean canPrintHighRes;

    /**
     * Gets the value of the password property.
     * 
     * @return
     *     possible object is
     *     {@link PasswordType }
     *     
     */
    public PasswordType getPassword() {
        return password;
    }

    /**
     * Sets the value of the password property.
     * 
     * @param value
     *     allowed object is
     *     {@link PasswordType }
     *     
     */
    public void setPassword(PasswordType value) {
        this.password = value;
    }

    public boolean isSetPassword() {
        return (this.password!= null);
    }

    /**
     * Gets the value of the canAssemble property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanAssemble() {
        if (canAssemble == null) {
            return true;
        } else {
            return canAssemble;
        }
    }

    /**
     * Sets the value of the canAssemble property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanAssemble(boolean value) {
        this.canAssemble = value;
    }

    public boolean isSetCanAssemble() {
        return (this.canAssemble!= null);
    }

    public void unsetCanAssemble() {
        this.canAssemble = null;
    }

    /**
     * Gets the value of the canExtractContent property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanExtractContent() {
        if (canExtractContent == null) {
            return true;
        } else {
            return canExtractContent;
        }
    }

    /**
     * Sets the value of the canExtractContent property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanExtractContent(boolean value) {
        this.canExtractContent = value;
    }

    public boolean isSetCanExtractContent() {
        return (this.canExtractContent!= null);
    }

    public void unsetCanExtractContent() {
        this.canExtractContent = null;
    }

    /**
     * Gets the value of the canExtractForAccessibility property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanExtractForAccessibility() {
        if (canExtractForAccessibility == null) {
            return true;
        } else {
            return canExtractForAccessibility;
        }
    }

    /**
     * Sets the value of the canExtractForAccessibility property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanExtractForAccessibility(boolean value) {
        this.canExtractForAccessibility = value;
    }

    public boolean isSetCanExtractForAccessibility() {
        return (this.canExtractForAccessibility!= null);
    }

    public void unsetCanExtractForAccessibility() {
        this.canExtractForAccessibility = null;
    }

    /**
     * Gets the value of the canFillInForm property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanFillInForm() {
        if (canFillInForm == null) {
            return true;
        } else {
            return canFillInForm;
        }
    }

    /**
     * Sets the value of the canFillInForm property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanFillInForm(boolean value) {
        this.canFillInForm = value;
    }

    public boolean isSetCanFillInForm() {
        return (this.canFillInForm!= null);
    }

    public void unsetCanFillInForm() {
        this.canFillInForm = null;
    }

    /**
     * Gets the value of the canModify property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanModify() {
        if (canModify == null) {
            return true;
        } else {
            return canModify;
        }
    }

    /**
     * Sets the value of the canModify property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanModify(boolean value) {
        this.canModify = value;
    }

    public boolean isSetCanModify() {
        return (this.canModify!= null);
    }

    public void unsetCanModify() {
        this.canModify = null;
    }

    /**
     * Gets the value of the canModifyAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanModifyAnnotations() {
        if (canModifyAnnotations == null) {
            return true;
        } else {
            return canModifyAnnotations;
        }
    }

    /**
     * Sets the value of the canModifyAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanModifyAnnotations(boolean value) {
        this.canModifyAnnotations = value;
    }

    public boolean isSetCanModifyAnnotations() {
        return (this.canModifyAnnotations!= null);
    }

    public void unsetCanModifyAnnotations() {
        this.canModifyAnnotations = null;
    }

    /**
     * Gets the value of the canPrint property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanPrint() {
        if (canPrint == null) {
            return true;
        } else {
            return canPrint;
        }
    }

    /**
     * Sets the value of the canPrint property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanPrint(boolean value) {
        this.canPrint = value;
    }

    public boolean isSetCanPrint() {
        return (this.canPrint!= null);
    }

    public void unsetCanPrint() {
        this.canPrint = null;
    }

    /**
     * Gets the value of the canPrintHighRes property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanPrintHighRes() {
        if (canPrintHighRes == null) {
            return true;
        } else {
            return canPrintHighRes;
        }
    }

    /**
     * Sets the value of the canPrintHighRes property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanPrintHighRes(boolean value) {
        this.canPrintHighRes = value;
    }

    public boolean isSetCanPrintHighRes() {
        return (this.canPrintHighRes!= null);
    }

    public void unsetCanPrintHighRes() {
        this.canPrintHighRes = null;
    }

}

==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/info/SecurityType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;


/**
 * <p>Java class for SecurityType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SecurityType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element name="password" type="{http://schema.webpdf.de/1.0/extraction/info}PasswordType" minOccurs="0"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attGroup ref="{http://schema.webpdf.de/1.0/extraction/info}securityFlags"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SecurityType", propOrder = {
    "password"
})
@JsonIgnoreProperties(ignoreUnknown = true)
public class SecurityType {

    protected PasswordType password;
    @XmlAttribute(name = "canAssemble")
    protected Boolean canAssemble;
    @XmlAttribute(name = "canExtractContent")
    protected Boolean canExtractContent;
    @XmlAttribute(name = "canExtractForAccessibility")
    protected Boolean canExtractForAccessibility;
    @XmlAttribute(name = "canFillInForm")
    protected Boolean canFillInForm;
    @XmlAttribute(name = "canModify")
    protected Boolean canModify;
    @XmlAttribute(name = "canModifyAnnotations")
    protected Boolean canModifyAnnotations;
    @XmlAttribute(name = "canPrint")
    protected Boolean canPrint;
    @XmlAttribute(name = "canPrintHighRes")
    protected Boolean canPrintHighRes;

    /**
     * Gets the value of the password property.
     * 
     * @return
     *     possible object is
     *     {@link PasswordType }
     *     
     */
    public PasswordType getPassword() {
        return password;
    }

    /**
     * Sets the value of the password property.
     * 
     * @param value
     *     allowed object is
     *     {@link PasswordType }
     *     
     */
    public void setPassword(PasswordType value) {
        this.password = value;
    }

    public boolean isSetPassword() {
        return (this.password!= null);
    }

    /**
     * Gets the value of the canAssemble property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanAssemble() {
        if (canAssemble == null) {
            return true;
        } else {
            return canAssemble;
        }
    }

    /**
     * Sets the value of the canAssemble property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanAssemble(boolean value) {
        this.canAssemble = value;
    }

    public boolean isSetCanAssemble() {
        return (this.canAssemble!= null);
    }

    public void unsetCanAssemble() {
        this.canAssemble = null;
    }

    /**
     * Gets the value of the canExtractContent property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanExtractContent() {
        if (canExtractContent == null) {
            return true;
        } else {
            return canExtractContent;
        }
    }

    /**
     * Sets the value of the canExtractContent property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanExtractContent(boolean value) {
        this.canExtractContent = value;
    }

    public boolean isSetCanExtractContent() {
        return (this.canExtractContent!= null);
    }

    public void unsetCanExtractContent() {
        this.canExtractContent = null;
    }

    /**
     * Gets the value of the canExtractForAccessibility property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanExtractForAccessibility() {
        if (canExtractForAccessibility == null) {
            return true;
        } else {
            return canExtractForAccessibility;
        }
    }

    /**
     * Sets the value of the canExtractForAccessibility property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanExtractForAccessibility(boolean value) {
        this.canExtractForAccessibility = value;
    }

    public boolean isSetCanExtractForAccessibility() {
        return (this.canExtractForAccessibility!= null);
    }

    public void unsetCanExtractForAccessibility() {
        this.canExtractForAccessibility = null;
    }

    /**
     * Gets the value of the canFillInForm property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanFillInForm() {
        if (canFillInForm == null) {
            return true;
        } else {
            return canFillInForm;
        }
    }

    /**
     * Sets the value of the canFillInForm property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanFillInForm(boolean value) {
        this.canFillInForm = value;
    }

    public boolean isSetCanFillInForm() {
        return (this.canFillInForm!= null);
    }

    public void unsetCanFillInForm() {
        this.canFillInForm = null;
    }

    /**
     * Gets the value of the canModify property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanModify() {
        if (canModify == null) {
            return true;
        } else {
            return canModify;
        }
    }

    /**
     * Sets the value of the canModify property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanModify(boolean value) {
        this.canModify = value;
    }

    public boolean isSetCanModify() {
        return (this.canModify!= null);
    }

    public void unsetCanModify() {
        this.canModify = null;
    }

    /**
     * Gets the value of the canModifyAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanModifyAnnotations() {
        if (canModifyAnnotations == null) {
            return true;
        } else {
            return canModifyAnnotations;
        }
    }

    /**
     * Sets the value of the canModifyAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanModifyAnnotations(boolean value) {
        this.canModifyAnnotations = value;
    }

    public boolean isSetCanModifyAnnotations() {
        return (this.canModifyAnnotations!= null);
    }

    public void unsetCanModifyAnnotations() {
        this.canModifyAnnotations = null;
    }

    /**
     * Gets the value of the canPrint property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanPrint() {
        if (canPrint == null) {
            return true;
        } else {
            return canPrint;
        }
    }

    /**
     * Sets the value of the canPrint property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanPrint(boolean value) {
        this.canPrint = value;
    }

    public boolean isSetCanPrint() {
        return (this.canPrint!= null);
    }

    public void unsetCanPrint() {
        this.canPrint = null;
    }

    /**
     * Gets the value of the canPrintHighRes property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanPrintHighRes() {
        if (canPrintHighRes == null) {
            return true;
        } else {
            return canPrintHighRes;
        }
    }

    /**
     * Sets the value of the canPrintHighRes property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanPrintHighRes(boolean value) {
        this.canPrintHighRes = value;
    }

    public boolean isSetCanPrintHighRes() {
        return (this.canPrintHighRes!= null);
    }

    public void unsetCanPrintHighRes() {
        this.canPrintHighRes = null;
    }

}
